@@ -15,7 +15,9 @@ import re
 import glob
 import requests
 import botocore
+import shutil
 from cogniceptshell.common import bcolors
+from cogniceptshell.common import generate_progress_bar
 from subprocess import DEVNULL
 
 class AgentLifeCycle:
@@ -351,16 +353,28 @@ class AgentLifeCycle:
         success_flag = True
         for image_name in images:
             i = i + 1
+            image_name_short = image_name.replace("412284733352.dkr.ecr.ap-southeast-1.amazonaws.com/", "cognicept/")
             try:
                 for status in object.docker_client.pull(image_name, stream = True, decode = True):
                     if("progress" not in status):
                         status["progress"] = ""
-                    print("[" + str(i) + "/" + str(N) + "]" + image_name + "-" + status["status"] + " " + status["progress"], end="")
-                print("[" + str(i) + "/" + str(N) + "]" + image_name + "-" + bcolors.OKBLUE + "OK" + bcolors.ENDC + "\033[K")
-            except docker.errors.ImageNotFound:
-                print("[" + str(i) + "/" + str(N) + "]" + image_name + "-" + bcolors.FAIL + "FAILED" + bcolors.ENDC + "\033[K")
-                success_flag = False
+                    if("status" not in status):
+                        status["status"] = "Error"
+                    terminal_size = shutil.get_terminal_size().columns
 
+                    progress = ""
+                    if("progressDetail" in status and "total" in status["progressDetail"]):
+                        progress = generate_progress_bar(status["progressDetail"]["current"], status["progressDetail"]["total"], 1 , 10)
+                    status = "[" + str(i) + "/" + str(N) + "] " + image_name_short + " - " + status["status"] + " " + progress
+                    print('{:{terminal_size}.{terminal_size}}'.format(status, terminal_size = terminal_size), end="\r", flush=True)
+                print("[" + str(i) + "/" + str(N) + "] " + image_name_short + " - " + bcolors.OKBLUE + "OK" + bcolors.ENDC + "\033[K")
+            except docker.errors.ImageNotFound:
+                print("[" + str(i) + "/" + str(N) + "] " + image_name_short + " - " + bcolors.FAIL + "FAILED" + bcolors.ENDC + "\033[K")
+                success_flag = False
+            except:
+                print("[" + str(i) + "/" + str(N) + "] " + image_name_short + " - " + bcolors.FAIL + "FAILED" + bcolors.ENDC + "\033[K")
+                success_flag = False
+                
         print("Info: Run `cognicept restart` to redeploy updated agents.")
         return success_flag
 
