@@ -14,7 +14,6 @@ import sys
 import re
 import requests
 import getpass
-import jwt
 import time
 
 
@@ -96,59 +95,17 @@ class Configuration:
         except IOError:
             print("Could not write into `" + object.env_path + "`. Please check write permission or run with `sudo`.")
 
-    def cognicept_login(object):
-        print("Please enter your Cognicept credentials.")
-
-        username = input("Username: ")
-        try:
-            password = getpass.getpass()
-        except Exception as error:
-            print('Error when reading password.')
-            return False
-
-        try:
-            resp = requests.post(object.get_cognicept_api_uri() + 'user/login', json = {"username": username, "password": password}, timeout = 5)
-            if resp.status_code != 200:
-                print('Login error: wrong credentials.')
-                return False
-
-            object.config["COGNICEPT_JWT"] = resp.json()["access_token"]
-        except requests.exceptions.Timeout:
-            print("Cognicept REST API error: time out.")
-            return
-        except requests.exceptions.TooManyRedirects:
-            print("Cognicept REST API error: Wrong endpoint.")
-            return
-        except:
-            print("Cognicept REST API error")
-            raise SystemExit()
-        object.save_config()
-
-
-
-        return True
-
-    def get_cognicept_jwt(object):
-        if "COGNICEPT_JWT" in object.config:
-            # check expiration of the current token
-            jwt_decoded = jwt.decode(object.config["COGNICEPT_JWT"], verify=False)
-            if ( jwt_decoded["exp"] >  time.time()):
-                # if not expired return token
-                return object.config["COGNICEPT_JWT"]
-            else:
-                print("Cognicept login expired.")
-        # try to login if token exists or expired
-        if(object.cognicept_login()):
-            return object.config["COGNICEPT_JWT"]
+    def get_cognicept_credentials(object):
+        if "COGNICEPT_ACCESS_KEY" in object.config:
+            return object.config["COGNICEPT_ACCESS_KEY"]   
         else:
-            # if all fails return empty string
-            return ""
+            print('COGNICEPT_ACCESS_KEY missing')
 
     def get_cognicept_api_uri(object):
         if "COGNICEPT_API_URI" in object.config:
             return object.config["COGNICEPT_API_URI"]
         else:
-            return "https://dev.cognicept.systems/api/v1/"
+            return "https://app.cognicept.systems/api/v1/"
 
     def get_field(object, field_name):
         if field_name in object.config:
@@ -267,3 +224,37 @@ class Configuration:
             return False
         
         return object.config["COG_ENABLE_SSH_KEY_AUTH"]
+
+    def cognicept_key_rotate(object,args):
+        print("Updating cloud credentials.")
+        try:
+            headers = {
+                'Authorization': 'Basic ' + object.get_cognicept_credentials()
+            }
+            resp = requests.get(object.get_cognicept_api_uri(
+            ) + 'aws/assume_role', headers = headers, timeout=5)
+            if resp.status_code != 200:
+                print('Login error: wrong credentials.')
+                return False
+
+            object.config["AWS_ACCESS_KEY_ID"] = resp.json()[
+                "AccessKeyId"]
+            object.config["AWS_SECRET_ACCESS_KEY"] = resp.json()[
+                "SecretAccessKey"]
+            object.config["AWS_SESSION_TOKEN"] = resp.json()[
+                "SessionToken"]
+            object.config["AWS_TOKEN_EXPIRATION"] = resp.json()[
+                "Expiration"]
+            print("Cloud access keys rotated successfully!")
+        except requests.exceptions.Timeout:
+            print("Cognicept REST API error: time out.")
+            return False
+        except requests.exceptions.TooManyRedirects:
+            print("Cognicept REST API error: Wrong endpoint.")
+            return False
+        except Exception as e:
+            print("Cognicept REST API error"+ str(e))
+            raise SystemExit()
+        object.save_config()
+
+        return True
